@@ -2,8 +2,7 @@ from django.conf import settings
 
 SETTING_NAME = "SCAN_MODELS"
 
-# todo: add custom validator to readme
-DEFAULT_SETTINGS = {"mapping": {}, "validator": "scan_models.validators.VeeValidate"}
+DEFAULT_SETTINGS = {"mapping": {}, "validator": "scan_models.validators.VeeValidate", "camelize": False}
 
 
 def get_setting(name: str):
